==> qwt-6.1.6-1-aarch64.pkg.tar.xz: usr/share/doc/qwt/html/class_qwt_abstract_scale_draw.js <==
var class_qwt_abstract_scale_draw =
[
    [ "ScaleComponents", "class_qwt_abstract_scale_draw.html#a0dd3ccdfa074fb6b1781b84ed2a4729a", null ],
    [ "ScaleComponent", "class_qwt_abstract_scale_draw.html#a26215d06a4d48adf401d0aa05d4193c5", [
      [ "Backbone", "class_qwt_abstract_scale_draw.html#a26215d06a4d48adf401d0aa05d4193c5a61a6c4f4dec2b089edfb655e2b21c3a2", null ],
      [ "Ticks", "class_qwt_abstract_scale_draw.html#a26215d06a4d48adf401d0aa05d4193c5a1f23d080ce1229a0c4f70469e88acce0", null ],
      [ "Labels", "class_qwt_abstract_scale_draw.html#a26215d06a4d48adf401d0aa05d4193c5ad2709d7efbb6f1618f0a8a3b6cafae96", null ]
    ] ],
    [ "QwtAbstractScaleDraw", "class_qwt_abstract_scale_draw.html#a19c944664a2e36f06ae71b745fbd442e", null ],
    [ "~QwtAbstractScaleDraw", "class_qwt_abstract_scale_draw.html#adc4d3f491b28ee39d728a4a4a9cdd494", null ],
    [ "draw", "class_qwt_abstract_scale_draw.html#ac4442d7480db1288971e7eac15142467", null ],
    [ "drawBackbone", "class_qwt_abstract_scale_draw.html#a15994a6033e689c3acdb8d83ae4f2a1c", null ],
    [ "drawLabel", "class_qwt_abstract_scale_draw.html#aa78dc8bf05a0224450c947af54128d8d", null ],
    [ "drawTick", "class_qwt_abstract_scale_draw.html#a31791e80bf07d23adbe500740aac5a58", null ],
    [ "enableComponent", "class_qwt_abstract_scale_draw.html#af975410588db6103f281e49d0b43c6a6", null ],
    [ "extent", "class_qwt_abstract_scale_draw.html#a87e21208e981457cde501054319c77e7", null ],
    [ "hasComponent", "class_qwt_abstract_scale_draw.html#a8a69a890d349a9e03c145b20b5835e8a", null ],
    [ "invalidateCache", "class_qwt_abstract_scale_draw.html#a4ed95cd23c5d779c1b05aa5295409aa6", null ],
    [ "label", "class_qwt_abstract_scale_draw.html#ac1d855f856b746559c41f4f06ec5442d", null ],
    [ "maxTickLength", "class_qwt_abstract_scale_draw.html#ab3713ea053eb3d6327b18a3d14c7b820", null ],
    [ "minimumExtent", "class_qwt_abstract_scale_draw.html#abdd97b4bedda111df8208ec96a894f8f", null ],
    [ "penWidth", "class_qwt_abstract_scale_draw.html#a400719a9bf1b916224d744e75d527989", null ],
    [ "scaleDiv", "class_qwt_abstract_scale_draw.html#ad15e796d2fd8bd1e2cfa66715bf58e2e", null ],
    [ "scaleMap", "class_qwt_abstract_scale_draw.html#ae7488eb63ad73a2e69acb29ff069c904", null ],
    [ "scaleMap", "class_qwt_abstract_scale_draw.html#a2582c30e82f8977877ac8044253f1fb8", null ],
    [ "setMinimumExtent", "class_qwt_abstract_scale_draw.html#ac174255c334b995ca010a6964597d5f2", null ],
    [ "setPenWidth", "class_qwt_abstract_scale_draw.html#a098e1f813077c9bb0c5f83266035943a", null ],
    [ "setScaleDiv", "class_qwt_abstract_scale_draw.html#a149792f955cc3f05c16362338bcc98c4", null ],
    [ "setSpacing", "class_qwt_abstract_scale_draw.html#a074675cd805656f0ae158f84745074af", null ],
    [ "setTickLength", "class_qwt_abstract_scale_draw.html#a7fed388e435aae791d61f48cc9ddf632", null ],
    [ "setTransformation", "class_qwt_abstract_scale_draw.html#a732d0e49c9092c48893b4f71cc7357db", null ],
    [ "spacing", "class_qwt_abstract_scale_draw.html#ad3b290a76426a1a22a870e84c1655666", null ],
    [ "tickLabel", "class_qwt_abstract_scale_draw.html#a9325b265f351e9135cdbb9368e53f68a", null ],
    [ "tickLength", "class_qwt_abstract_scale_draw.html#a52fe17714fe96564b0d88af27e96e58f", null ]
];

==> qwt-6.2.0-1-aarch64.pkg.tar.xz: usr/share/doc/qwt/html/class_qwt_abstract_scale_draw.js <==
var class_qwt_abstract_scale_draw =
[
    [ "ScaleComponents", "class_qwt_abstract_scale_draw.html#af900d3a139451b70e6ce5acee5e2df7e", null ],
    [ "ScaleComponent", "class_qwt_abstract_scale_draw.html#a26215d06a4d48adf401d0aa05d4193c5", [
      [ "Backbone", "class_qwt_abstract_scale_draw.html#a26215d06a4d48adf401d0aa05d4193c5a61a6c4f4dec2b089edfb655e2b21c3a2", null ],
      [ "Ticks", "class_qwt_abstract_scale_draw.html#a26215d06a4d48adf401d0aa05d4193c5a1f23d080ce1229a0c4f70469e88acce0", null ],
      [ "Labels", "class_qwt_abstract_scale_draw.html#a26215d06a4d48adf401d0aa05d4193c5ad2709d7efbb6f1618f0a8a3b6cafae96", null ]
    ] ],
    [ "QwtAbstractScaleDraw", "class_qwt_abstract_scale_draw.html#a19c944664a2e36f06ae71b745fbd442e", null ],
    [ "~QwtAbstractScaleDraw", "class_qwt_abstract_scale_draw.html#adc4d3f491b28ee39d728a4a4a9cdd494", null ],
    [ "draw", "class_qwt_abstract_scale_draw.html#ac4442d7480db1288971e7eac15142467", null ],
    [ "drawBackbone", "class_qwt_abstract_scale_draw.html#a15994a6033e689c3acdb8d83ae4f2a1c", null ],
    [ "drawLabel", "class_qwt_abstract_scale_draw.html#aa78dc8bf05a0224450c947af54128d8d", null ],
    [ "drawTick", "class_qwt_abstract_scale_draw.html#a31791e80bf07d23adbe500740aac5a58", null ],
    [ "enableComponent", "class_qwt_abstract_scale_draw.html#af975410588db6103f281e49d0b43c6a6", null ],
    [ "extent", "class_qwt_abstract_scale_draw.html#a87e21208e981457cde501054319c77e7", null ],
    [ "hasComponent", "class_qwt_abstract_scale_draw.html#a8a69a890d349a9e03c145b20b5835e8a", null ],
    [ "invalidateCache", "class_qwt_abstract_scale_draw.html#a4ed95cd23c5d779c1b05aa5295409aa6", null ],
    [ "label", "class_qwt_abstract_scale_draw.html#ac1d855f856b746559c41f4f06ec5442d", null ],
    [ "maxTickLength", "class_qwt_abstract_scale_draw.html#ab3713ea053eb3d6327b18a3d14c7b820", null ],
    [ "minimumExtent", "class_qwt_abstract_scale_draw.html#abdd97b4bedda111df8208ec96a894f8f", null ],
    [ "penWidthF", "class_qwt_abstract_scale_draw.html#ad0e889e3a5b5af8adb0d6a507e7fbc95", null ],
    [ "scaleDiv", "class_qwt_abstract_scale_draw.html#ad15e796d2fd8bd1e2cfa66715bf58e2e", null ],
    [ "scaleMap", "class_qwt_abstract_scale_draw.html#ae7488eb63ad73a2e69acb29ff069c904", null ],
    [ "scaleMap", "class_qwt_abstract_scale_draw.html#a2582c30e82f8977877ac8044253f1fb8", null ],
    [ "setMinimumExtent", "class_qwt_abstract_scale_draw.html#ac174255c334b995ca010a6964597d5f2", null ],
    [ "setPenWidthF", "class_qwt_abstract_scale_draw.html#a6401e26332d65433e0b881400a1ce03b", null ],
    [ "setScaleDiv", "class_qwt_abstract_scale_draw.html#a149792f955cc3f05c16362338bcc98c4", null ],
    [ "setSpacing", "class_qwt_abstract_scale_draw.html#a074675cd805656f0ae158f84745074af", null ],
    [ "setTickLength", "class_qwt_abstract_scale_draw.html#a7fed388e435aae791d61f48cc9ddf632", null ],
    [ "setTransformation", "class_qwt_abstract_scale_draw.html#a732d0e49c9092c48893b4f71cc7357db", null ],
    [ "spacing", "class_qwt_abstract_scale_draw.html#ad3b290a76426a1a22a870e84c1655666", null ],
    [ "tickLabel", "class_qwt_abstract_scale_draw.html#a9325b265f351e9135cdbb9368e53f68a", null ],
    [ "tickLength", "class_qwt_abstract_scale_draw.html#a52fe17714fe96564b0d88af27e96e58f", null ]
];
